#!/bin/bash

NET_NAME="eiru"
ODOO_IMAGE="odoo/eiru:1.4"
ODOO_PATH="/srv/odoo"
DB_CONTAINER="database"

start_database_system()
{
	# start postgresql
	docker start $DB_CONTAINER
	# start pgbouncer
	docker run \
		--name pgbouncer \
		--volume /srv/pgbouncer/config:/etc/pgbouncer \
		--volume /srv/pgbouncer/log:/var/log/pgbouncer \
		--net $NET_NAME \
		--ip 172.19.0.3 \
		--tty pgbouncer:alpine
}

start_odoo_system()
{
	docker run \
		--name $1 \
		--publish "$2:8069" \
		--volume "$ODOO_PATH/$1/conf:/etc/odoo" \
		--volume "$ODOO_PATH/$1/custom-addons:/mnt/extra-addons" \
		--volume "$ODOO_PATH/$1/files:/var/lib/odoo" \
		--link "$DB_CONTAINER:db" \
		--net $NET_NAME \
		--ip $3 \
		--tty $ODOO_IMAGE
}

start_odoo_systems()
{
	start_odoo_system golden 10000 "172.19.0.100"
	start_odoo_system athletic 10500 "172.19.0.101"
	start_odoo_system topjeans 11000 "172.19.0.102"
	start_odoo_system kava 11500 "172.19.0.103"
	start_odoo_system amojeans 12500 "172.19.0.105"
	start_odoo_system world 13000 "172.19.0.106"
	start_odoo_system clasi_calse 13500 "172.19.0.107"
	start_odoo_system tuspasos 15000 "172.19.0.108"
}

start_monitor_systems()
{
	docker start influxdb
	docker start telegraf
	docker start grafana
}

if [ ! -x "$(command -v docker)" ]; then
    echo "cannot bootup systems"
    exit 1
fi

start_database_system
start_odoo_systems
start_monitor_systems

exit 0
